@@ -7,3 +7,6 @@ __version__ = pkg_resources.get_distribution("pybsc").version
 
 
 from pybsc.split import nsplit
+
+from pybsc.iter_utils import pairwise
+from pybsc.iter_utils import triplewise
